==> orca-42.0-x86_64-1_gfs.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/share/help/bg/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/bg/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/cs/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/cs/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/de/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/de/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/el/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/el/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/es/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/es/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/fr/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/fr/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/gl/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/gl/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/hu/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/hu/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/id/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/id/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/pt_BR/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/pt_BR/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/sl/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/sl/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/sv/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/sv/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/uk/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/uk/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )

==> orca-42.1-x86_64-1_gfs.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/share/help/bg/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/bg/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/cs/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/cs/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/da/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/da/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/de/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/de/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/el/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/el/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/es/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/es/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/fr/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/fr/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/gl/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/gl/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/hu/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/hu/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/id/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/id/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/pt_BR/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/pt_BR/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/sl/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/sl/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/sv/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/sv/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
( cd usr/share/help/uk/orca/figures ; rm -rf orca-logo.png )
( cd usr/share/help/uk/orca/figures ; ln -sf /usr/share/help/C/orca/figures/orca-logo.png orca-logo.png )
